chiark / gitweb /
Allow binding to a chosen address.
[tripe] / tripe.h
diff --git a/tripe.h b/tripe.h
index 3c0a15419630cf16001a4f611814a9b85d40dde1..1f73d6ba22ddcf5a33072189666351e8de68e7a9 100644 (file)
--- a/tripe.h
+++ b/tripe.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: tripe.h,v 1.14 2003/04/06 10:36:33 mdw Exp $
+ * $Id: tripe.h,v 1.15 2003/05/16 12:09:03 mdw Exp $
  *
  * Main header file for TrIPE
  *
@@ -29,6 +29,9 @@
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: tripe.h,v $
+ * Revision 1.15  2003/05/16 12:09:03  mdw
+ * Allow binding to a chosen address.
+ *
  * Revision 1.14  2003/04/06 10:36:33  mdw
  * Rearrange so as not to include Linux headers unless we need to.
  *
@@ -893,14 +896,15 @@ extern const addr *p_addr(peer */*p*/);
 
 /* --- @p_init@ --- *
  *
* Arguments:  @unsigned port@ = port number to listen to
  *
  * Returns:    ---
  *
  * Use:                Initializes the peer system; creates the socket.
  */
 
-extern void p_init(unsigned /*port*/);
+extern void p_init(struct in_addr /*addr*/, unsigned /*port*/);
 
 /* --- @p_port@ --- *
  *
@@ -893,14 +896,15 @@ extern const addr *p_addr(peer */*p*/);
 /* --- @p_init@ --- *
  *
- * Arguments:  @unsigned port@ = port number to listen to
+ * Arguments:  @struct in_addr addr@ = address to bind to
+ *             @unsigned port@ = port number to listen to
  *
  * Returns:    ---